package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.GtgsYwUserMapper;
import com.ruoyi.system.domain.GtgsYwUser;
import com.ruoyi.system.service.IGtgsYwUserService;
import com.ruoyi.common.core.text.Convert;

/**
 * 工商账号管理Service业务层处理
 *
 * @author ruoyi
 * @date 2019-12-14
 */
@Service
public class GtgsYwUserServiceImpl implements IGtgsYwUserService
{
    @Autowired
    private GtgsYwUserMapper gtgsYwUserMapper;

    /**
     * 查询工商账号管理
     *
     * @param id 工商账号管理ID
     * @return 工商账号管理
     */
    @Override
    public GtgsYwUser selectGtgsYwUserById(Long id)
    {
        return gtgsYwUserMapper.selectGtgsYwUserById(id);
    }

    /**
     * 查询工商账号管理
     *
     * @return 工商账号管理
     */
    @Override
    public  GtgsYwUser selectGtgsYwUserByRemark(String remark)
    {
        return gtgsYwUserMapper.selectGtgsYwUserByRemark(remark);
    }

    /**
     * 查询工商账号管理列表
     *
     * @param gtgsYwUser 工商账号管理
     * @return 工商账号管理
     */
    @Override
    public List<GtgsYwUser> selectGtgsYwUserList(GtgsYwUser gtgsYwUser)
    {
        return gtgsYwUserMapper.selectGtgsYwUserList(gtgsYwUser);
    }

    /**
     * 新增工商账号管理
     *
     * @param gtgsYwUser 工商账号管理
     * @return 结果
     */
    @Override
    public int insertGtgsYwUser(GtgsYwUser gtgsYwUser)
    {
        return gtgsYwUserMapper.insertGtgsYwUser(gtgsYwUser);
    }

    /**
     * 修改工商账号管理
     *
     * @param gtgsYwUser 工商账号管理
     * @return 结果
     */
    @Override
    public int updateGtgsYwUser(GtgsYwUser gtgsYwUser)
    {
        return gtgsYwUserMapper.updateGtgsYwUser(gtgsYwUser);
    }

    /**
     * 删除工商账号管理对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteGtgsYwUserByIds(String ids)
    {
        return gtgsYwUserMapper.deleteGtgsYwUserByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除工商账号管理信息
     *
     * @param id 工商账号管理ID
     * @return 结果
     */
    public int deleteGtgsYwUserById(Long id)
    {
        return gtgsYwUserMapper.deleteGtgsYwUserById(id);
    }
}
